### Model 3 Density independent (alternative only southern Sweden)
## Model_3_DID_alt

rm(list=ls())
library(rjags)
setwd("/xxx/xxx/xxx")

y=read.csv("Andren_Data_1.csv", sep=",") 

head(y)


#Function to get beta shape parameters from moments
shape_from_stats <- function(mu = mu.global, sigma = sigma.global){
		 a <-(mu^2-mu^3-mu*sigma^2)/sigma^2
		 b <- (mu-2*mu^2+mu^3-sigma^2+mu*sigma^2)/sigma^2
		shape_ps <- c(a,b)
		return(shape_ps)
}

shapes=shape_from_stats(.184,.013)
#check prior on p
x = seq(0,1,.001)
p=dbeta(x,shapes[1],shapes[2])
plot(x,p,typ="l",xlim=c(.1,.3))

n.year = nrow(y)

#Data for JAGS
data = list(
	y1 = y$Lynx.FG[1],
	n.year = n.year,
	y.a=shapes[1],
	y.b=shapes[2],
	y.H=y$Harvest,
	y=y$Lynx.FG
)

str(data)

inits = list(
  list(c0=0.2, sigma.p = .1, sigma.o = 6),
  list(c0=0.3, sigma.p = .15,	sigma.o = 7),
  list(c0=0.25, sigma.p = .2, sigma.o = 8)
	)

### Density independent
model = "Model_3_alt_JAGS.R" 

n.update=50000
n.iter=100000
n.adapt=20000
n.thin=1

jm = jags.model(model,data=data,inits=inits, n.adapt=n.adapt, n.chains=length(inits))
update(jm, n.iter=n.update)

z = coda.samples(jm,variable.names=c("c0", "sigma.o", "sigma.p", "p"), n.iter=n.iter, thin=n.thin)

zj=jags.samples(jm,variable.names=c("N","fg","p","predict.N","pvalue","fit","fit.new","c0","sigma.o","sigma.p","rate.obs","shape.obs"), n.iter=n.iter, thin=n.thin)
summary(z)
plot(z)
heidel.diag(z)
gelman.diag(z)
#look at Bayesian P
zj$pvalue
pp = zj$pvalue

#Do goodness of fit plot.
par(mfrow=c(1,1))
plot(zj$fit.new[,,],zj$fit[,,], xlab = "Discrepancy observed", ylab= "Discrepancy simulated", cex=.05, xlim=c(0,2000), ylim=c(0,2000))
abline(0,1)
p[1]=mean(pp[,,])
text(400,1800, paste("Bayesian P value = ", as.character(signif(p[1],2))))

##############Plots of posterior densities
par(mfrow=c(1,2))
x=seq(-1,1,0.001)

hist(zj$c0[,,], xlab="c0 - south", main="", freq=FALSE, breaks=100, xlim=c(0,0.4)) #southern Sweden
c0_y=dnorm(x,0, 100)
lines(x,c0_y, ylim=c(0,50), col="red", lwd=2)

hist(zj$p[,,], xlab = "conversion factor (p)", main="", freq=FALSE, breaks=80, xlim=c(0.1,0.3))
shapes=shape_from_stats(.184,.013)
x = seq(0,1,.001)
p=dbeta(x,shapes[1],shapes[2])
lines(x,p, col="red", lwd=2)

hist(zj$sigma.o[,,], xlab="sigma.o", main="", freq=FALSE, breaks=50, xlim=c(0,100))
xx = seq(0,100,0.001)
sigma.o_y = dunif(xx,0,100)
lines(xx,sigma.o_y ,col="red", lwd=2)

hist(zj$sigma.p[,,], xlab="sigma.p", main="", freq=FALSE, breaks=80, xlim=c(0,1))
xxx = seq(0,10,0.001)
sigma.p_y = dunif(xxx,0,10)
lines(xxx,sigma.p_y ,col="red", lwd=2)


ecdf(zj$c0[,,])(0)

lambda = exp(zj$c0[,,])
mean(lambda)
sd(lambda)

summary(exp(zj$c0),quantile,c(.025,.5,.975))$stat

