## Model 4 density independent including vehicle collisions
## Model_4_DID_vehicle

rm(list=ls())
library(rjags)
setwd("/xxx/xxx/xxx/")

y=read.csv("Andren_Data_2.csv", sep=",") 

head(y)


#Function to get beta shape parameters from moments
shape_from_stats <- function(mu = mu.global, sigma = sigma.global){
		 a <-(mu^2-mu^3-mu*sigma^2)/sigma^2
		 b <- (mu-2*mu^2+mu^3-sigma^2+mu*sigma^2)/sigma^2
		shape_ps <- c(a,b)
		return(shape_ps)
}


# get shape parameters for conversion factor 
shapes=shape_from_stats(.1835,.01343)
#check prior on p
x = seq(0,1,.001)
p=dbeta(x,shapes[1],shapes[2])
plot(x,p,typ="l",xlim=c(.1,.3))


# indexing 4 regions (reg 5 = 8 years, reg 6 = 10 years, reg 7 = 10 years, reg 8 = 15 years)
n.region = 4
n.year = as.numeric(4)
n.year[1]=8
n.year[2]=10
n.year[3]=10
n.year[4]=18

n.area=c(1,1,1,2)
  
index=matrix(ncol=n.year[4], nrow=n.region)
count=0
for(i in 1:n.region){
  for (t in 1:n.year[i]){
    count=count+1
    index[i,t]=count
  }
}

  
#Data for JAGS
data = list(
	y1 = y$Lynx.FG[index[1,1]],
	y2 = y$Lynx.FG[index[2,1]],
	y3 = y$Lynx.FG[index[3,1]],
	y4 = y$Lynx.FG[index[4,1]],
	n.year = n.year,
	n.region = n.region,
	index = index,
	n.area = n.area,
	y.a=shapes[1],
	y.b=shapes[2],
	y.H=y$Harvest,
	y=y$Lynx.FG,
	t1=y$Traffic_1,
	t2=y$Traffic_2
)

str(data)

inits = list(
  list(d0=rep(0.2,2), sigma.p = .1, sigma.o = 6),
  list(d0=rep(0.3,2), sigma.p = .15,	sigma.o = 7),
  list(d0=rep(0.25,2), sigma.p = .2, sigma.o = 8)
	)

### JAGS model
model = "Model_4_JAGS.R" 

n.update=50000
n.iter=100000
n.adapt=20000
n.thin=1

jm = jags.model(model,data=data,inits=inits, n.adapt=n.adapt, n.chains=length(inits))
update(jm, n.iter=n.update)

z = coda.samples(jm,variable.names=c("d0", "sigma.o", "sigma.p", "p"), n.iter=n.iter, thin=n.thin)

zj=jags.samples(jm,variable.names=c("N[1,1:8]","N[2,1:10]","N[3,1:10]","N[4,1:18]","fg[1,1:8]","fg[2,1:10]","fg[3,1:10]","fg[4,1:18]","p","predict.N","pvalue","fit","fit.new","d0","sigma.o","sigma.p","rate.obs","shape.obs"), n.iter=n.iter, thin=n.thin)
summary(z)
plot(z)
heidel.diag(z)
gelman.diag(z)
#look at Bayesian P
zj$pvalue
pp = zj$pvalue

#Do goodness of fit plot.
par(mfrow=c(1,1))
plot(zj$fit.new[1,,],zj$fit[1,,], xlab = "Discrepancy observed", ylab= "Discrepancy simulated", cex=.05, xlim=c(0,2000), ylim=c(0,2000))
abline(0,1)
p[1]=mean(pp[1,,])
text(400,1800, paste("Bayesian P value = ", as.character(signif(p[1],2))))

plot(zj$fit.new[2,,],zj$fit[2,,], xlab = "Discrepancy observed", ylab= "Discrepancy simulated", cex=.05, xlim=c(0,2000), ylim=c(0,2000))
abline(0,1)
p[2]=mean(pp[2,,])
text(400,1800, paste("Bayesian P value = ", as.character(signif(p[2],2))))

plot(zj$fit.new[3,,],zj$fit[3,,], xlab = "Discrepancy observed", ylab= "Discrepancy simulated", cex=.05, xlim=c(0,2000), ylim=c(0,2000))
abline(0,1)
p[3]=mean(pp[3,,])
text(400,1800, paste("Bayesian P value = ", as.character(signif(p[3],2))))

plot(zj$fit.new[4,,],zj$fit[4,,], xlab = "Discrepancy observed", ylab= "Discrepancy simulated", cex=.05, xlim=c(0,2000), ylim=c(0,2000))
abline(0,1)
p[4]=mean(pp[4,,])
text(400,1800, paste("Bayesian P value = ", as.character(signif(p[4],2))))


##############Plots of posterior densities
par(mfrow=c(1,2))
x=seq(-1,1,0.001)

hist(zj$d0[2,,], xlab="d0 - south", main="", freq=FALSE, breaks=100, xlim=c(0,0.4)) #southern Sweden
d0_y=dnorm(x,0, 100)
lines(x,d0_y, ylim=c(0,50), col="red", lwd=2)

hist(zj$d0[1,,], xlab="d0 - central", main="", freq=FALSE, breaks=100, xlim=c(0,0.4)) #central Sweden
lines(x,d0_y, ylim=c(0,50), col="red", lwd=2)

hist(zj$p[,,], xlab = "conversion factor (p)", main="", freq=FALSE, breaks=80, xlim=c(0.1,0.3))
shapes=shape_from_stats(.1835,.01343)
x = seq(0,1,.001)
p=dbeta(x,shapes[1],shapes[2])
lines(x,p, col="red", lwd=2)

hist(zj$sigma.o[,,], xlab="sigma.o", main="", freq=FALSE, breaks=50, xlim=c(0,100))
xx = seq(0,100,0.001)
sigma.o_y = dunif(xx,0,100)
lines(xx,sigma.o_y ,col="red", lwd=2)

hist(zj$sigma.p[,,], xlab="sigma.p", main="", freq=FALSE, breaks=80, xlim=c(0,1))
xxx = seq(0,10,0.001)
sigma.p_y = dunif(xxx,0,10)
lines(xxx,sigma.p_y ,col="red", lwd=2)


ecdf(zj$d0[1,,])(0)
ecdf(zj$d0[2,,])(0)

#######################################
## compare growth rate between areas - central (1) vs southernmost (2) Sweden
mean(zj$d0[1,,])
sd(zj$d0[1,,])

mean(zj$d0[2,,])
sd(zj$d0[2,,])

summary((zj$d0),quantile,c(.025,.5,.975))$stat

lambda.1 = exp(zj$d0[1,,])
mean(lambda.1)
sd(lambda.1)

lambda.2 = exp(zj$d0[2,,])
mean(lambda.2)
sd(lambda.2)

summary(exp(zj$d0),quantile,c(.025,.5,.975))$stat

ecdf(zj$d0[1,,]-zj$d0[2,,])(0) ## probability that growth rate in southernmost Sweden is higher than in central Sweden
1-ecdf(zj$d0[1,,]-zj$d0[2,,])(0) ## probability that growth rate in southernmost Sweden is lower than in central Sweden

